

### <a name="manual"></a> Chapter block

Inserts headings.

| Key       |      Description      | Default    |
|:----------|:--------------------- |:-----------|
| type      |  chapter              |
| title     |  title of the chapter | No title |
| level     |  (optional) chapter hierarchy level (0,1,2,3,...) | 0 |
| toc       |  (optional) link with table of content | True |
| numbered  |  (optional) displays numbering in front of title | True |
| label     |  (optional) label for clickable link in same document |  |

Example:
```YAML
- type    : chapter
  level   : 0
  title   : Some Chapter Title
```

Back to [Documentation](../../../README.md#block_basic)
